:py:mod:`byma.iteral`
=====================

.. py:module:: byma.iteral


Submodules
----------
.. toctree::
   :titlesonly:
   :maxdepth: 1

   Iteral/index.rst
   Newton/index.rst
   OrthogonalSubspace/index.rst


Package Contents
----------------

Classes
~~~~~~~

.. autoapisummary::

   byma.iteral.Iteral




.. py:class:: Iteral


   Defines default options for the Iterative methods sub-package


